@@ -27,7 +27,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "0.2.1"
+__version__ = "0.4.0"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -42,6 +42,7 @@ import sys
 import tempfile
 from collections import deque, OrderedDict
 from itertools import chain
+from importlib import import_module
 from pathlib import Path
 from urllib.parse import urlparse
 
@@ -146,6 +147,24 @@ class CompatibilityError(MicropipenvException):
     """Raised when internal pip API is incompatible with micropipenv."""
 
 
+class NotSupportedError(MicropipenvException):
+    """Raised when the given feature is not supported by micropipenv."""
+
+
+def _import_toml():  # type: () -> Any
+    """Import and return toml or pytoml module (in this order)."""
+    for module in "toml", "pytoml":
+        try:
+            return import_module(module)
+        except ImportError:
+            pass
+    else:
+        raise ExtrasMissing(
+            "Failed to import toml needed for parsing Pipfile, please install micropipenv "
+            "with toml extra: pip install micropipenv[toml]"
+        )
+
+
 def _traverse_up_find_file(file_name):  # type: (str) -> str
     """Traverse the root up, find the given file by name and return its path."""
     path = os.getcwd()
@@ -181,13 +200,7 @@ def _read_pipfile_lock():  # type: () -> Any
 
 def _read_pipfile():  # type: () -> Any
     """Find and read Pipfile."""
-    try:
-        import toml
-    except ImportError as exc:
-        raise ExtrasMissing(
-            "Failed to import toml needed for parsing Pipfile, please install micropipenv "
-            "with toml extra: pip install micropipenv[toml]"
-        ) from exc
+    toml = _import_toml()
 
     pipfile_path = _traverse_up_find_file("Pipfile")
 
@@ -202,13 +215,7 @@ def _read_pipfile():  # type: () -> Any
 
 def _read_poetry():  # type: () -> Tuple[MutableMapping[str, Any], MutableMapping[str, Any]]
     """Find and read poetry.lock and pyproject.toml."""
-    try:
-        import toml
-    except ImportError as exc:
-        raise ExtrasMissing(
-            "Failed to import toml needed for parsing poetry.lock and pyproject.toml as used by Poetry, "
-            "please install micropipenv with toml extra: pip install micropipenv[toml]"
-        ) from exc
+    toml = _import_toml()
 
     poetry_lock_path = _traverse_up_find_file("poetry.lock")
     pyproject_toml_path = _traverse_up_find_file("pyproject.toml")
@@ -332,13 +339,22 @@ def _instantiate_package_finder(pip_session):  # type: (PipSession) -> PackageFi
         from pip._internal.models.search_scope import SearchScope
         from pip._internal.models.selection_prefs import SelectionPreferences
 
+        selection_prefs = SelectionPreferences(allow_yanked=True,)
+        search_scope = SearchScope([], [])
+
         try:
             from pip._internal.index.collector import LinkCollector
         except ModuleNotFoundError:
-            from pip._internal.collector import LinkCollector
+            try:
+                from pip._internal.collector import LinkCollector
+            except ModuleNotFoundError:  # pip>=19.2<20
+                return PackageFinder.create(
+                    session=pip_session,
+                    selection_prefs=selection_prefs,
+                    search_scope=search_scope
+                )
 
-        link_collector = LinkCollector(session=pip_session, search_scope=SearchScope([], []),)
-        selection_prefs = SelectionPreferences(allow_yanked=True,)
+        link_collector = LinkCollector(session=pip_session, search_scope=search_scope)
         return PackageFinder.create(link_collector=link_collector, selection_prefs=selection_prefs,)
 
 
@@ -351,6 +367,13 @@ def _get_requirement_info(requirement):  # type: (ParsedRequirement) -> Dict[str
     # Editable requirements.
     editable = getattr(requirement, "editable", False) or getattr(requirement, "is_editable", False)
 
+    # Check for unsupported VCS.
+    link_url = getattr(requirement, "requirement", None) or getattr(requirement, "link", None)
+    if link_url and str(link_url).startswith(("hg+", "svn+", "bzr+")):
+        raise NotSupportedError(
+            "Non-Git VCS requirement {!r} is not supported yet".format(str(link_url))
+        )
+
     is_url = False
     req = None
     if hasattr(requirement, "req"):
@@ -446,9 +469,9 @@ def _get_requirement_info(requirement):  # type: (ParsedRequirement) -> Dict[str
     }
 
 
-def _requirements2pipfile_lock():  # type: () -> Dict[str, Any]
+def _requirements2pipfile_lock(requirements_txt_path=None):  # type: (Optional[str]) -> Dict[str, Any]
     """Parse requirements.txt file and return its Pipfile.lock representation."""
-    requirements_txt_path = _traverse_up_find_file("requirements.txt")
+    requirements_txt_path = requirements_txt_path or _traverse_up_find_file("requirements.txt")
 
     pip_session = PipSession()
     finder = _instantiate_package_finder(pip_session)
@@ -635,8 +658,8 @@ def _poetry2pipfile_lock(
 
         if "source" in entry:
             if entry["source"]["type"] != "git":
-                raise NotImplementedError(
-                    "Micropipenv supports Git VCS, got {} instead".format(entry["source"]["type"])
+                raise NotSupportedError(
+                    "micropipenv supports Git VCS, got {} instead".format(entry["source"]["type"])
                 )
 
             requirement["git"] = entry["source"]["url"]
@@ -708,7 +731,7 @@ def install_requirements(pip_bin=_PIP_BIN, *, pip_args=None):  # type: (str, Opt
     requirements_txt_path = _traverse_up_find_file("requirements.txt")
 
     try:
-        pipfile_lock = _requirements2pipfile_lock()
+        pipfile_lock = _requirements2pipfile_lock(requirements_txt_path)
         # Deploy set to false as there is no Pipfile to check against.
         install_pipenv(pip_bin, pipfile_lock=pipfile_lock, pip_args=pip_args, deploy=False)
     except PipRequirementsNotLocked:
